==> jc-1.4.0.tar.gz: polyglot/ext/jl/qq/sym.h <==
// public class polyglot.ext.jl.qq.sym

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c015a345790ac23d polyglot_ext_jl_qq_sym

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_jl_qq_sym_H_
#define _JC_polyglot_ext_jl_qq_sym_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_qq_sym$sub_refs	_jc_polyglot_ext_jl_qq_sym$sub_refs;
typedef struct _jc_polyglot_ext_jl_qq_sym$sub_nonrefs	_jc_polyglot_ext_jl_qq_sym$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_sym$refs	_jc_polyglot_ext_jl_qq_sym$refs;
typedef struct _jc_polyglot_ext_jl_qq_sym$nonrefs	_jc_polyglot_ext_jl_qq_sym$nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_sym$object	_jc_polyglot_ext_jl_qq_sym$object;

typedef struct _jc_polyglot_ext_jl_qq_sym$fields_struct	_jc_polyglot_ext_jl_qq_sym$fields_struct;
typedef const struct _jc_polyglot_ext_jl_qq_sym$vmethods	_jc_polyglot_ext_jl_qq_sym$vmethods;
typedef const struct _jc_polyglot_ext_jl_qq_sym$vtable	_jc_polyglot_ext_jl_qq_sym$vtable;
typedef const struct _jc_polyglot_ext_jl_qq_sym$vtype	_jc_polyglot_ext_jl_qq_sym$vtype;

// Class fields structure
struct _jc_polyglot_ext_jl_qq_sym$fields_struct {
	jint	ABSTRACT;
	jint	AND;
	jint	ANDAND;
	jint	ANDEQ;
	jint	ASSERT;
	jint	BOOLEAN;
	jint	BOOLEAN__5fLITERAL;
	jint	BREAK;
	jint	BYTE;
	jint	CASE;
	jint	CATCH;
	jint	CHAR;
	jint	CHARACTER__5fLITERAL;
	jint	CLASS;
	jint	COLON;
	jint	COMMA;
	jint	COMMA__5fDECL;
	jint	COMMA__5fEXPR;
	jint	COMMA__5fFORM;
	jint	COMMA__5fLIST;
	jint	COMMA__5fMEMB;
	jint	COMMA__5fSTMT;
	jint	COMMA__5fTYPE;
	jint	COMP;
	jint	CONST;
	jint	CONTINUE;
	jint	DEFAULT;
	jint	DIV;
	jint	DIVEQ;
	jint	DO;
	jint	DOT;
	jint	DOUBLE;
	jint	DOUBLE__5fLITERAL;
	jint	ELSE;
	jint	EOF;
	jint	EQ;
	jint	EQEQ;
	jint	EXTENDS;
	jint	FINAL;
	jint	FINALLY;
	jint	FLOAT;
	jint	FLOAT__5fLITERAL;
	jint	FOR;
	jint	GOTO;
	jint	GT;
	jint	GTEQ;
	jint	IDENTIFIER;
	jint	IF;
	jint	IMPLEMENTS;
	jint	IMPORT;
	jint	INSTANCEOF;
	jint	INT;
	jint	INTEGER__5fLITERAL;
	jint	INTERFACE;
	jint	JLGEN__5fTOKEN__5f0;
	jint	JLGEN__5fTOKEN__5f1;
	jint	JLGEN__5fTOKEN__5f2;
	jint	JLGEN__5fTOKEN__5f3;
	jint	JLGEN__5fTOKEN__5f4;
	jint	JLGEN__5fTOKEN__5f5;
	jint	LBRACE;
	jint	LBRACK;
	jint	LONG;
	jint	LONG__5fLITERAL;
	jint	LPAREN;
	jint	LSHIFT;
	jint	LSHIFTEQ;
	jint	LT;
	jint	LTEQ;
	jint	MINUS;
	jint	MINUSEQ;
	jint	MINUSMINUS;
	jint	MOD;
	jint	MODEQ;
	jint	MULT;
	jint	MULTEQ;
	jint	NATIVE;
	jint	NEW;
	jint	NOT;
	jint	NOTEQ;
	jint	NULL__5fLITERAL;
	jint	OR;
	jint	OREQ;
	jint	OROR;
	jint	PACKAGE;
	jint	PLUS;
	jint	PLUSEQ;
	jint	PLUSPLUS;
	jint	PRIVATE;
	jint	PROTECTED;
	jint	PUBLIC;
	jint	QUESTION;
	jint	RBRACE;
	jint	RBRACK;
	jint	RETURN;
	jint	RPAREN;
	jint	RSHIFT;
	jint	RSHIFTEQ;
	jint	SEMICOLON;
	jint	SHORT;
	jint	STATIC;
	jint	STRICTFP;
	jint	STRING__5fLITERAL;
	jint	SUPER;
	jint	SWITCH;
	jint	SYNCHRONIZED;
	jint	THIS;
	jint	THROW;
	jint	THROWS;
	jint	TRANSIENT;
	jint	TRY;
	jint	URSHIFT;
	jint	URSHIFTEQ;
	jint	VOID;
	jint	VOLATILE;
	jint	WHILE;
	jint	XOR;
	jint	XOREQ;
	jint	error;
};
extern _jc_polyglot_ext_jl_qq_sym$fields_struct _jc_polyglot_ext_jl_qq_sym$class_fields;

// Constructors
extern void _jc_polyglot_ext_jl_qq_sym$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_ext_jl_qq_sym$object *);

// Virtual methods structure
struct _jc_polyglot_ext_jl_qq_sym$vmethods {
};

// Vtable
struct _jc_polyglot_ext_jl_qq_sym$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_qq_sym$vmethods	polyglot_ext_jl_qq_sym;
};

// Vtype
struct _jc_polyglot_ext_jl_qq_sym$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_qq_sym$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_sym$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_sym$refs {
    _jc_polyglot_ext_jl_qq_sym$sub_refs	polyglot_ext_jl_qq_sym;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_sym$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_sym$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_qq_sym$sub_nonrefs	polyglot_ext_jl_qq_sym;
};

// Object instance structure
struct _jc_polyglot_ext_jl_qq_sym$object {
	_jc_polyglot_ext_jl_qq_sym$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_qq_sym$vtype	*vtype;
	_jc_polyglot_ext_jl_qq_sym$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_qq_sym$vtype _jc_polyglot_ext_jl_qq_sym$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_qq_sym, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_qq_sym$class_object;

#endif	/* _JC_polyglot_ext_jl_qq_sym_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/qq/sym.h <==
// public class polyglot.ext.jl.qq.sym

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c015a345790ac23d polyglot_ext_jl_qq_sym

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_jl_qq_sym_H_
#define _JC_polyglot_ext_jl_qq_sym_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_qq_sym$sub_refs	_jc_polyglot_ext_jl_qq_sym$sub_refs;
typedef struct _jc_polyglot_ext_jl_qq_sym$sub_nonrefs	_jc_polyglot_ext_jl_qq_sym$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_sym$refs	_jc_polyglot_ext_jl_qq_sym$refs;
typedef struct _jc_polyglot_ext_jl_qq_sym$nonrefs	_jc_polyglot_ext_jl_qq_sym$nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_sym$object	_jc_polyglot_ext_jl_qq_sym$object;

typedef struct _jc_polyglot_ext_jl_qq_sym$fields_struct	_jc_polyglot_ext_jl_qq_sym$fields_struct;
typedef const struct _jc_polyglot_ext_jl_qq_sym$vmethods	_jc_polyglot_ext_jl_qq_sym$vmethods;
typedef const struct _jc_polyglot_ext_jl_qq_sym$vtable	_jc_polyglot_ext_jl_qq_sym$vtable;
typedef const struct _jc_polyglot_ext_jl_qq_sym$vtype	_jc_polyglot_ext_jl_qq_sym$vtype;

// Class fields structure
struct _jc_polyglot_ext_jl_qq_sym$fields_struct {
	jint	ABSTRACT;
	jint	AND;
	jint	ANDAND;
	jint	ANDEQ;
	jint	ASSERT;
	jint	BOOLEAN;
	jint	BOOLEAN__5fLITERAL;
	jint	BREAK;
	jint	BYTE;
	jint	CASE;
	jint	CATCH;
	jint	CHAR;
	jint	CHARACTER__5fLITERAL;
	jint	CLASS;
	jint	COLON;
	jint	COMMA;
	jint	COMMA__5fDECL;
	jint	COMMA__5fEXPR;
	jint	COMMA__5fFORM;
	jint	COMMA__5fLIST;
	jint	COMMA__5fMEMB;
	jint	COMMA__5fSTMT;
	jint	COMMA__5fTYPE;
	jint	COMP;
	jint	CONST;
	jint	CONTINUE;
	jint	DEFAULT;
	jint	DIV;
	jint	DIVEQ;
	jint	DO;
	jint	DOT;
	jint	DOUBLE;
	jint	DOUBLE__5fLITERAL;
	jint	ELSE;
	jint	EOF;
	jint	EQ;
	jint	EQEQ;
	jint	EXTENDS;
	jint	FINAL;
	jint	FINALLY;
	jint	FLOAT;
	jint	FLOAT__5fLITERAL;
	jint	FOR;
	jint	GOTO;
	jint	GT;
	jint	GTEQ;
	jint	IDENTIFIER;
	jint	IF;
	jint	IMPLEMENTS;
	jint	IMPORT;
	jint	INSTANCEOF;
	jint	INT;
	jint	INTEGER__5fLITERAL;
	jint	INTERFACE;
	jint	JLGEN__5fTOKEN__5f0;
	jint	JLGEN__5fTOKEN__5f1;
	jint	JLGEN__5fTOKEN__5f2;
	jint	JLGEN__5fTOKEN__5f3;
	jint	JLGEN__5fTOKEN__5f4;
	jint	JLGEN__5fTOKEN__5f5;
	jint	LBRACE;
	jint	LBRACK;
	jint	LONG;
	jint	LONG__5fLITERAL;
	jint	LPAREN;
	jint	LSHIFT;
	jint	LSHIFTEQ;
	jint	LT;
	jint	LTEQ;
	jint	MINUS;
	jint	MINUSEQ;
	jint	MINUSMINUS;
	jint	MOD;
	jint	MODEQ;
	jint	MULT;
	jint	MULTEQ;
	jint	NATIVE;
	jint	NEW;
	jint	NOT;
	jint	NOTEQ;
	jint	NULL__5fLITERAL;
	jint	OR;
	jint	OREQ;
	jint	OROR;
	jint	PACKAGE;
	jint	PLUS;
	jint	PLUSEQ;
	jint	PLUSPLUS;
	jint	PRIVATE;
	jint	PROTECTED;
	jint	PUBLIC;
	jint	QUESTION;
	jint	RBRACE;
	jint	RBRACK;
	jint	RETURN;
	jint	RPAREN;
	jint	RSHIFT;
	jint	RSHIFTEQ;
	jint	SEMICOLON;
	jint	SHORT;
	jint	STATIC;
	jint	STRICTFP;
	jint	STRING__5fLITERAL;
	jint	SUPER;
	jint	SWITCH;
	jint	SYNCHRONIZED;
	jint	THIS;
	jint	THROW;
	jint	THROWS;
	jint	TRANSIENT;
	jint	TRY;
	jint	URSHIFT;
	jint	URSHIFTEQ;
	jint	VOID;
	jint	VOLATILE;
	jint	WHILE;
	jint	XOR;
	jint	XOREQ;
	jint	error;
};
extern _jc_polyglot_ext_jl_qq_sym$fields_struct _jc_polyglot_ext_jl_qq_sym$class_fields;

// Constructors
extern void _jc_polyglot_ext_jl_qq_sym$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_ext_jl_qq_sym$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_ext_jl_qq_sym$vmethods {
};

// Vtable
struct _jc_polyglot_ext_jl_qq_sym$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_qq_sym$vmethods	polyglot_ext_jl_qq_sym;
};

// Vtype
struct _jc_polyglot_ext_jl_qq_sym$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_qq_sym$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_sym$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_sym$refs {
    _jc_polyglot_ext_jl_qq_sym$sub_refs	polyglot_ext_jl_qq_sym;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_sym$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_sym$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_qq_sym$sub_nonrefs	polyglot_ext_jl_qq_sym;
};

// Object instance structure
struct _jc_polyglot_ext_jl_qq_sym$object {
	_jc_polyglot_ext_jl_qq_sym$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_qq_sym$vtype	*vtype;
	_jc_polyglot_ext_jl_qq_sym$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_qq_sym$vtype _jc_polyglot_ext_jl_qq_sym$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_qq_sym, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_qq_sym$class_object;

#endif	/* _JC_polyglot_ext_jl_qq_sym_H_ */
